import axios from 'axios';

import { Product } from '../cart/CartTypes';
import { mockedStocks } from './mocks';

const BASE_URL = "https://" + process.env.REACT_APP_BACK_URL + "/api/v1";
const APIKEY = process.env.REACT_APP_BACK_API_KEY || 'theapikey'

// Fetch items from API
export async function getItems(): Promise<Product[]> {
  // Fetch stocks data
  const stocks: any[] = await axios.get(`${BASE_URL}/stock`, {
    headers: {
      'Content-Type': 'application/json',
      'apikey': APIKEY,
    }
  }).then(({ data }) => data)
    .catch(error => {
      console.error(error);
      return mockedStocks;
    });

  // Format products data
  const products = stocks.map(stock => new Product({
    id: stock.item.id,
    name: stock.item.name,
    category: stock.item.category.name,
    price: stock.item.price,
    subscriberPrice: stock.item.subscriber_price,
    stock: stock.quantity
  }));

  // console.table(products);

  return products;
}

export async function updateStock(itemId: number, stock: number): Promise<boolean> {
  const response = await axios.put(`${BASE_URL}/stock`, {
    item_id: itemId,
    quantity: stock
  }, {
    headers: {
      'Content-Type': 'application/json',
      'apikey': APIKEY,
    }
  }).then(({ status }) => status === 200)
    .catch(error => {
      console.error(error);
      return false;
    });

  return response;
};

export async function getCategories(): Promise<any[]> {
  const categories = await axios.get(`${BASE_URL}/category`, {
    headers: {
      'Content-Type': 'application/json',
      'apikey': APIKEY,
    }
  }).then(({ data }) => data)
    .catch(error => {
      console.error(error);
      return [];
    });

  return categories;
}

export async function addItem(name: string, price: number, priceAdherant: number, stock: number, category_id: any): Promise<any> {
  // Create the item without stock
  let item = await axios.post(`${BASE_URL}/item`, {
    name: name,
    price: price,
    subscriber_price: priceAdherant,
    category: category_id,
  }, {
    headers: {
      'Content-Type': 'application/json',
      'apikey': APIKEY,
    }}).then(({ data }) => {
      //console.log(data)
      return data;
    })
    .catch(error => {
      console.error(error);
      return null;
    });

  // Create the stock
  if (item) {
    await axios.put(`${BASE_URL}/stock`, {
      item_id: item.id,
      quantity: stock,
    }, {
      headers: {
        'Content-Type': 'application/json',
        'apikey': APIKEY,
      }}).then(({ data }) => data)
      .catch(error => {
        console.error(error);
        return [];
      });
  } else {
    console.error("Error while creating item");
  }
}
