import axios from 'axios';

import { mockedUsers } from './mocks';

export class User {
  nom: string;
  prenom: string;
  email: string;
  studentNumber: string;
  adherant: boolean;
  picture?: string;

  constructor(nom, prenom, email, studentNumber, adherant, picture?) {
    this.nom = nom;
    this.prenom = prenom;
    this.email = email;
    this.studentNumber = studentNumber;
    this.adherant = adherant;
    this.picture = picture;
  }
};

const BASE_URL = "https://" + process.env.REACT_APP_STUDENT_URL;

// Fetch users from API
export async function getUsers(): Promise<User[]> {
  // Fetch users data
  const usersData: any[] = await axios.get(`${BASE_URL}/api/etudiants`, {
    headers: {
      'Content-Type': 'application/json',
    }
  }).then(({ data }) => data)
    .catch(error => {
      console.error(error);
      return mockedUsers;
    });

  // Format users data
  const users = usersData.map(user => new User(
    user.lastname,
    user.firstname,
    user.email,
    user.student_number,
    validateSubscriptionDate(user.date_subscription),
    user.picture
  ));

  return users;
};

export async function setAdhesion(studentNumber: string) : Promise<boolean> {
  // Set adhesion for given user
  const success = await axios.post(`${BASE_URL}/api/pay_adhesion`, {
    'student_number': studentNumber ?? '12345678'
  }, {
    headers: {
      'Content-Type': 'application/json',
    }
  }).then(({ status }) => status === 200)
    .catch(error => {
      console.error(error);
      return false;
    });

  return success;
}

function validateSubscriptionDate(dateStr: string): boolean {
  const YEAR_IN_MS = 31536000000;
  const date = Date.parse(dateStr) ?? Date.parse('01 Jan 1970 00:00:00 GMT');
  const now = Date.now();
  // Valid subscription if it was made less than a year ago
  return (now - date) < YEAR_IN_MS;
}
