import {useContext, useState, useEffect} from 'react';

import {
  CubeTransparentIcon,
  ShoppingCartIcon,
} from '@heroicons/react/outline';

import { addToCart } from '../cart/CartActions';
import { Product } from "../cart/CartTypes";
import { cartContext } from '../cart/CartStore';

const SellListItem = ({product}: {product: Product}) => {
  const { cartState, dispatch } = useContext(cartContext);

  const [item, setItem] = useState(product);
  useEffect(() => {
    // Set item from product in cartState.cart
    let itemInCart = cartState.cart.find(item => item.name === product.name);
    if (itemInCart) {
      setItem(itemInCart);
    }
  }, [cartState.cart, product.name]);

  function addProductToCart() {
    // product.stock--;
    // cartState.totalPrice += product.price;
    addToCart(cartState.cart, dispatch, product);
  }

  function renderPrice(price: number): string {
    // Render price with currency and fix displaying of price
    return `${price.toFixed(2).replace(".", ",")} €`;
  }

  function renderStock(stock: number): string {
    if (stock === 0) {
      return 'bg-red-100 text-red-800';
    } else if (stock <= 5) {
      return 'bg-orange-100 text-orange-800';
    } else {
      return 'bg-green-100 text-green-800';
    }
  }

  function getStockWithCart(element: Product): number {
    if (element.quantity !== undefined) {
      return element.stock - element.quantity;
    }
    return element.stock;
  }

  return (
    <li className="col-span-1 bg-white rounded-lg shadow divide-y divide-gray-200">
      <div className="w-full flex items-center justify-between p-6 space-x-6">
        <div className="flex-1 truncate">
          <div className="flex items-center space-x-3">
            <h3 className="text-gray-900 text-sm font-medium truncate">{item.name}</h3>
            <span className={"flex-shrink-0 inline-block px-2 py-0.5 text-xs font-medium rounded-full " + renderStock(getStockWithCart(item))}>
              {getStockWithCart(item)}
            </span>
          </div>
          <p className="mt-1 text-gray-500 text-sm truncate">{renderPrice(item.price)}</p>
        </div>
      </div>
      <div>
        <div className="-mt-px flex divide-x divide-gray-200">
          <div className="-ml-px w-0 flex-1 flex">
            {getStockWithCart(item) > 0
              ? <button
                //onClick={() => addToCart(cartState.cart, dispatch, item)}
                onClick={() => addProductToCart()}
                disabled={getStockWithCart(item) === 0}
                className="relative w-0 flex-1 inline-flex items-center justify-center py-4 text-sm text-gray-700 font-medium border border-transparent rounded-b-lg hover:text-gray-500 active:bg-indigo-100 active:text-gray-900 focus:shadow-outline-indigo hover:border-indigo-700 transition ease-in-out duration-150"
              >
                <ShoppingCartIcon className="w-5 h-5 mr-2" aria-hidden="true" />
                Ajouter
              </button>
              : <span className="relative w-0 flex-1 inline-flex items-center justify-center py-4 text-sm text-red-700 font-medium border border-transparent rounded-b-lg"><CubeTransparentIcon className="w-5 h-5 mr-2" aria-hidden="true" />
                Rupture de stock
              </span>
            }
          </div>
        </div>
      </div>
    </li>
  );
};

export default SellListItem;