import { useState, useEffect } from 'react';
import { CollectionIcon, EmojiSadIcon } from '@heroicons/react/outline';

import SellListItem from "../components/sellListItem";
import Cart from '../components/sell/cart';

import { Product } from '../cart/CartTypes'
import { getItems } from '../apis/back';


const Sell = () => {
  let [search, setSearch] = useState("");
  let [productsList, setProductsList] = useState<Product[]>([]);
  let [rawProductList, setRawProductList] = useState<Product[]>([]);
  
  useEffect(() => {
    // Filter products by name with the search term
    setProductsList(rawProductList.filter(product => {
      return product.name.toLowerCase().includes(search.toLowerCase());
    }));
  }, [search, rawProductList]);

  useEffect(() => {
    getItems().then((items) => {
      setRawProductList(items);
      setProductsList(items);
    }).catch((_) => {
      setRawProductList([]);
      setProductsList([]);
    });
  }, []);

  return (
    <div>
      <div className="max-w-7xl mx-auto px-4 sm:px-6 md:px-8">
        {rawProductList.length > 0 &&
          <div className="max-w-7xl mx-auto px-4 sm:px-6 md:px-8 pb-5">
            <label htmlFor="search" className="block text-sm font-medium text-gray-700">Recherche</label>
            <div className="mt-1 relative flex items-center">
              <input
                type="text"
                name="search"
                id="search"
                value={search}
                onChange={(e) => { setSearch(e.target.value) }}
                className="shadow-sm focus:ring-indigo-500 focus:border-indigo-500 block w-full pr-12 sm:text-sm border-gray-300 rounded-md"
              />
            </div>
          </div>
        }
        {productsList.length > 0
          ? [...Array.from(new Set(productsList.map(item => item.category)))].map((category) => (
            <div key={category}>
              <h1 className="text-lg font-medium py-2 pt-4">{category}</h1>
              <ul className="grid grid-cols-1 gap-6 sm:grid-cols-2 lg:grid-cols-5">
                {productsList.filter((p) => p.category === category).map((product) => (
                  <SellListItem product={product} key={product.name} />
                ))}
              </ul>
            </div>))
          : <div className="text-center w-full mt-10">
            <EmojiSadIcon className="mx-auto h-12 w-12 text-gray-400" />
            <h3 className="mt-2 text-sm font-medium text-gray-900">Aucun produit trouvé !</h3>
            {rawProductList.length > 0 &&
              <>
                <p className="mt-1 text-sm text-gray-500">Essayez de réduire vos critères de recherche.</p>
                <div className="mt-6">
                  <button
                    type="button"
                    onClick={() => setSearch("")}
                    className="inline-flex items-center px-4 py-2 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                  >
                    <CollectionIcon className="-ml-1 mr-2 h-5 w-5" aria-hidden="true" />
                    Afficher tout
                  </button>
                </div>
              </>
            }
          </div>
        }
      </div>
      <Cart />
    </div>
  );
};

export default Sell;
